# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: colabo/flow/audit/audit.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='colabo/flow/audit/audit.proto',
  package='colabo.flow',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1d\x63olabo/flow/audit/audit.proto\x12\x0b\x63olabo.flow\"\xfa\x01\n\x12SubmitAuditRequest\x12\n\n\x02id\x18\x32 \x01(\t\x12\x0c\n\x04time\x18\x33 \x01(\t\x12\x11\n\tbpmn_type\x18\x04 \x01(\t\x12\x14\n\x0c\x62pmn_subtype\x18\x05 \x01(\t\x12\x17\n\x0f\x62pmn_subsubtype\x18\x06 \x01(\t\x12\x0e\n\x06\x66lowId\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06userId\x18\x34 \x01(\t\x12\x11\n\tsessionId\x18\x35 \x01(\t\x12\x16\n\x0e\x66lowInstanceId\x18\x03 \x01(\t\x12\x18\n\x10implementationId\x18\x36 \x01(\t\x12\x15\n\rimplementerId\x18\x37 \x01(\t\",\n\x10SubmitAuditReply\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04time\x18\x02 \x01(\t2S\n\x05\x41udit\x12J\n\x06submit\x12\x1f.colabo.flow.SubmitAuditRequest\x1a\x1d.colabo.flow.SubmitAuditReply\"\x00\x62\x06proto3')
)




_SUBMITAUDITREQUEST = _descriptor.Descriptor(
  name='SubmitAuditRequest',
  full_name='colabo.flow.SubmitAuditRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='colabo.flow.SubmitAuditRequest.id', index=0,
      number=50, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='colabo.flow.SubmitAuditRequest.time', index=1,
      number=51, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bpmn_type', full_name='colabo.flow.SubmitAuditRequest.bpmn_type', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bpmn_subtype', full_name='colabo.flow.SubmitAuditRequest.bpmn_subtype', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bpmn_subsubtype', full_name='colabo.flow.SubmitAuditRequest.bpmn_subsubtype', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flowId', full_name='colabo.flow.SubmitAuditRequest.flowId', index=5,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='colabo.flow.SubmitAuditRequest.name', index=6,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userId', full_name='colabo.flow.SubmitAuditRequest.userId', index=7,
      number=52, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='colabo.flow.SubmitAuditRequest.sessionId', index=8,
      number=53, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flowInstanceId', full_name='colabo.flow.SubmitAuditRequest.flowInstanceId', index=9,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='implementationId', full_name='colabo.flow.SubmitAuditRequest.implementationId', index=10,
      number=54, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='implementerId', full_name='colabo.flow.SubmitAuditRequest.implementerId', index=11,
      number=55, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=297,
)


_SUBMITAUDITREPLY = _descriptor.Descriptor(
  name='SubmitAuditReply',
  full_name='colabo.flow.SubmitAuditReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='colabo.flow.SubmitAuditReply.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='colabo.flow.SubmitAuditReply.time', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=343,
)

DESCRIPTOR.message_types_by_name['SubmitAuditRequest'] = _SUBMITAUDITREQUEST
DESCRIPTOR.message_types_by_name['SubmitAuditReply'] = _SUBMITAUDITREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubmitAuditRequest = _reflection.GeneratedProtocolMessageType('SubmitAuditRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBMITAUDITREQUEST,
  __module__ = 'colabo.flow.audit.audit_pb2'
  # @@protoc_insertion_point(class_scope:colabo.flow.SubmitAuditRequest)
  ))
_sym_db.RegisterMessage(SubmitAuditRequest)

SubmitAuditReply = _reflection.GeneratedProtocolMessageType('SubmitAuditReply', (_message.Message,), dict(
  DESCRIPTOR = _SUBMITAUDITREPLY,
  __module__ = 'colabo.flow.audit.audit_pb2'
  # @@protoc_insertion_point(class_scope:colabo.flow.SubmitAuditReply)
  ))
_sym_db.RegisterMessage(SubmitAuditReply)



_AUDIT = _descriptor.ServiceDescriptor(
  name='Audit',
  full_name='colabo.flow.Audit',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=345,
  serialized_end=428,
  methods=[
  _descriptor.MethodDescriptor(
    name='submit',
    full_name='colabo.flow.Audit.submit',
    index=0,
    containing_service=None,
    input_type=_SUBMITAUDITREQUEST,
    output_type=_SUBMITAUDITREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUDIT)

DESCRIPTOR.services_by_name['Audit'] = _AUDIT

# @@protoc_insertion_point(module_scope)



# NOTE: In general we should be carefull with importing additional modules in __init__.py because 
# they are imported any time any module or sub-module is required
# import `ColaboFlowAudit` class from the local (notice: `.`) file `colaboflow_audit_client`
from .colaboflow_audit_client import ColaboFlowAudit

# provide the `ColaboFlowAudit` class directly importable from the `audit` namespace
__all__ = ['ColaboFlowAudit']



# -*- coding: utf-8 -*-
#!/usr/bin/python

from __future__ import print_function

import random

import grpc

from . import audit_pb2
from . import audit_pb2_grpc

class ColaboFlowAudit():

    def __init__(self):
        # NOTE(gRPC Python Team): .close() is possible on a channel and should be
        # used in circumstances in which the with statement does not fit the needs
        # of the code.
        socketUrl = 'localhost:50505'
        print("Initializing gRPC at: %s" % (socketUrl))
        self.channel = grpc.insecure_channel(socketUrl)
        # to call service methods, we first need to create a stub.
        self.stub = audit_pb2_grpc.AuditStub(self.channel)

    def audit_submit(self, auditRequest):
        auditReply = self.stub.submit(auditRequest)
        if not auditReply.id or not auditReply.time:
            print("Server returned incomplete auditReply")
        else:
            print("Audit result is %s" % (auditReply))
        return auditReply
